<?php
/**
 * Partner API Library
 * 
 * @copyright Copyright (c) 2015 Unizeto Technologies SA
 * @license license.txt
 */

require_once 'operation.php';
require_once ROOTDIR.'/modules/servers/CERTUM_Certificates//certumPartnerAPI/messages/messageChangeVerification.php';
require_once ROOTDIR.'/modules/servers/CERTUM_Certificates//certumPartnerAPI/messages/messageChangeVerificationResponse.php';

/*
<operation name="addSanVerification" parameterOrder="addSanVerification">
	<input message="tns:PartnerServicePortType_addSanVerification">
	</input>
	<output message="tns:PartnerServicePortType_addSanVerificationResponse">
	</output>
</operation>
*/

/**
 * This class represents the addSanVerification WSDL operation.
 *
 * It is based on the PartnerAPIOperation class and derives some properties and methods from that class.
 *
 * @method PartnerAPIMessageChangeVerificationResponse getResponseMessage() A complete response from a service
 * 
 * @package operations
 */
class PartnerAPIOperationChangeVerification extends PartnerAPIOperation {

    /**
     * @var PartnerAPIMessageChangeVerification
     */
    protected $_input = NULL;
    
    /**
     * @var PartnerAPIMessageChangeVerificationResponse
     */
    protected $_output = NULL;

    /**
     * @var string
     */
    protected $_operation = 'addSanVerification';
    
    /**
     * The constructor.
     * 
     * It initializes input and output data.
     */
    public function __construct() {
        $this->_input  = new PartnerAPIMessageChangeVerification();
        $this->_output = new PartnerAPIMessageChangeVerificationResponse();
    }

    /**
     * Sets an order ID for the request.
     *
     * Setting this value is required.
     *
     * @param string $orderID
     * @return PartnerAPIOperationChangeVerification
     */
    public function setOrderID($orderID) {
    	$this->_input->addSanVerification->setOrderID($orderID);
    	return $this;
    }
    
    public function setSANApprover($method, $email, $prefix, $notification)
    {
        $sanApprover = $this->_input->addSanVerification->SANApprover;
        
        if (is_null($sanApprover)) {
            $sanApprover = new PartnerAPITypeSanApprovers();
        }
        
        $sanApprover->setApproverMethod($method);

        if($method == 'ADMIN')
        {
            if($prefix)
            {
                $sanApprover->setApproverEmailPrefix($prefix);
            }
        }
        else 
        {
            if($email)
            {
                $sanApprover->setApproverEmail($email);
            }
        }

        $sanApprover->setVerificationNotificationEnabled(false);
        if($notification)
        {
            $sanApprover->setVerificationNotificationEnabled(true);
        }
        
        return $this;

    }
}
