<?php

namespace MGModule\CERTUM_Certificates\helpers\AjaxRequests;

use MGModule\CERTUM_Certificates\helpers\Ajax;
use MGModule\CERTUM_Certificates\helpers\Product;
use MGModule\CERTUM_Certificates\helpers\Domain;
use MGModule\CERTUM_Certificates\helpers\SslService;
use WHMCS\Database\Capsule;
use PartnerAPIService;

require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Ajax.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Product.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."SslService.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Domain.php";
require_once dirname(dirname(__DIR__)).DIRECTORY_SEPARATOR."certumPartnerAPI".DIRECTORY_SEPARATOR."service.php";

class ReissueCertificate extends Ajax
{
    public function __construct($params = [])
    {
        parent::__construct($params);
    }
    
    public function action($parameters)
    {   
        if(empty($parameters['csr']))
        {
            throw new \Exception("'CSR' parameter is required");
        }
        if(empty($parameters['csr_serial']))
        {
            throw new \Exception("'Serial Number' parameter is required");
        }

        $product = new Product($parameters['productId']);
        $configuration = $product->getConfiguration();

        $api = new PartnerAPIService($configuration->configoption1, $configuration->configoption2, $configuration->configoption10);
        
        $approversDB = Capsule::table('certum_approvers')->where('serviceid', $parameters['serviceId'])->first();
        

        $sslService = new SslService($parameters['serviceId']);
	$sslService->setApiHandler($api);

	$lastDNS = $sslService->getLastCertificateDNS();
    
        $approversData = unserialize($approversDB->data);
       

        $op = $api->operationReissueCertificate();
        
        $op
            ->setCSR(trim($parameters['csr']))
            ->setSerialNumber($parameters['csr_serial']);
        
        if(!empty($parameters['sans']))
        {
            $op->setSANApprover($parameters['method'], $parameters['email'], $parameters['emailprefix'], $parameters['approvenotification']);
        }
        
//        if(empty($parameters['sans']) && !empty($lastDNS) && !empty($approversDB) && count($lastDNS) > 1)
//        {
//            $op->setSANApprover($approversData['approvermethod'], $approversData['approveremailaddress'], $approversData['approveremailprefix'], $approversData['approvenotification']);
//        }

        foreach($parameters['sans'] as $san)
        {
            $op->addSANEntry($san['domain']);

            if($san['prefix_www'] == 1)
            {
                $op->addSANEntry("www.".$san['domain']);
            }
        }
        
//        if(empty($parameters['sans']) && !empty($lastDNS) && !empty($approversDB) && count($lastDNS) > 1)
//        {
//            foreach($lastDNS as $san)
//            {
//                $op->addSANEntry(trim($san));
//            }
//        }
        
        if (!$op->call()) {
            $error = $op->getErrorTexts();

            if ($error[0]['text']) 
            {
                throw new \Exception($error[0]['text']);
            } 
            else 
            {
                $errors = $op->getErrors();
                throw new \Exception(CERTUM_Certificates_translate('reissueerror') . $errors[0]->errorCode);
            }
        }

        return ["result" => "success"];
    }
}