<?php

namespace MGModule\CERTUM_Certificates\helpers\AjaxRequests;

use MGModule\CERTUM_Certificates\helpers\Ajax;
use MGModule\CERTUM_Certificates\helpers\Product;
use PartnerAPIService;
use WHMCS\Database\Capsule as DB;

require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Ajax.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Product.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."SslService.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Domain.php";
require_once dirname(dirname(__DIR__)).DIRECTORY_SEPARATOR."certumPartnerAPI".DIRECTORY_SEPARATOR."service.php";

class RenewCertificate extends Ajax
{
    public function __construct($params = [])
    {
        parent::__construct($params);
    }
    
    public function action($parameters)
    {   
        if(!isset($parameters['csr']) || empty($parameters['csr']))
        {
            throw new \Exception('Please fill field "CSR"');
        }
        
        if((!isset($parameters['serial']) || empty($parameters['serial'])) && (!isset($parameters['pem']) || empty($parameters['pem'])))
        {
            throw new \Exception('Please fill field "serial" or "pem"');
        }
        
        if(isset($parameters['method']) && ($parameters['method'] == 'FILE' || $parameters['method'] == 'DNS') && empty($parameters['email']))
        {
            throw new \Exception('Please provide email address');
        }
        
        if(isset($parameters['method']) && ($parameters['method'] == 'FILE' || $parameters['method'] == 'DNS') && !filter_var($parameters['email'], FILTER_VALIDATE_EMAIL)) {
            throw new \Exception('Email address is incorrect!');
        }
        
        $data = openssl_csr_get_subject($parameters['csr']);
        $domain = $data['CN'];
   
        if (empty($domain)) {
             throw new \Exception('Invalid CSR');
        }
        
        $serviceid = $parameters['serviceId'];
        
        $renewals = DB::table('certum_renewals')->where('serviceid', $serviceid)->first();
        if(isset($renewals->serviceid))
        {
            DB::table('certum_renewals')->where('serviceid', $serviceid)->update([
                'serial' => $parameters['serial'],
                'pem' => $parameters['pem'],
                'csr' => $parameters['csr']
            ]);
        }
        else
        {
            DB::table('certum_renewals')->insert([
                'serviceid' => $serviceid,
                'serial' => $parameters['serial'],
                'pem' => $parameters['pem'],
                'csr' => $parameters['csr']
            ]);
        }
        
        $approvers = DB::table('certum_approvers')->where('serviceid', $serviceid)->first();
        if(isset($approvers->serviceid))
        {
            DB::table('certum_approvers')->where('serviceid', $serviceid)->update([
                'data' => serialize([
                    'approvermethod' => $parameters['method'],
                    'approveremailprefix' => $parameters['emailprefix'],
                    'approveremailaddress' => $parameters['email'],
                    'approvenotification' => $parameters['approvenotification']
                ])
            ]);
        }
        else
        {
            DB::table('certum_approvers')->insert([
                'serviceid' => $serviceid,
                'data' => serialize([
                    'approvermethod' => $parameters['method'],
                    'approveremailprefix' => $parameters['emailprefix'],
                    'approveremailaddress' => $parameters['email'],
                    'approvenotification' => $parameters['approvenotification']
                ])
            ]);
        }
        
        return ["result" => "success"];
    }
}