<?php

namespace MGModule\CERTUM_Certificates\helpers\AjaxRequests;

use MGModule\CERTUM_Certificates\helpers\Ajax;
use MGModule\CERTUM_Certificates\helpers\Product;
use MGModule\CERTUM_Certificates\helpers\SslService;

use PartnerAPIService;
use WHMCS\Database\Capsule as DB;

require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Ajax.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Product.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."SslService.php";
require_once dirname(__DIR__).DIRECTORY_SEPARATOR."Domain.php";
require_once dirname(dirname(__DIR__)).DIRECTORY_SEPARATOR."certumPartnerAPI".DIRECTORY_SEPARATOR."service.php";

class RevokeCertificate extends Ajax
{
    public function __construct($params = [])
    {
        parent::__construct($params);
    }

    public function action($params)
    {
        if(empty($params['serial_number']))
        {
            throw new \Exception("Serial Number is required!");
        }

        $product = new Product($params['productId']);
        $configuration = $product->getConfiguration();

        $api = new PartnerAPIService($configuration->configoption1, $configuration->configoption2, $configuration->configoption10);

        $revokeOperation = $api->operationRevokeCertificate();

        $revokeOperation
            ->setSerialNumber($params['serial_number'])
            ->setRevocationReason($params['reason']);

        if (!empty($params['revokationNotes']))
        {
            $revokeOperation
                ->setNote(str_replace("\n", " ", $params['revokationNotes']));
        }

        if (!empty($params['compromitationDate']))
        {
            $revokeOperation
                ->setKeyCompromitationDate($params['compromitationDate']);
        }

        if (!$revokeOperation->call()) {
            $error = $revokeOperation->getErrorTexts();

            if ($error[0]['text'])
            {
                throw new \Exception($error[0]['text']);
            }
            else
            {
                $errors = $revokeOperation->getErrors();
                throw new \Exception(CERTUM_Certificates_translate('reissueerror') . $errors[0]->errorCode);
            }
        }

        return ["result" => "success"];
    }
}