<?php

namespace MGModule\CERTUM_Certificates\helpers;

require_once 'Configuration/S_Mime.php';
require_once 'Configuration/DocumentSigning.php';
require_once 'Configuration/Trusted.php';
require_once 'Configuration/EmailIdIndividual.php';
require_once 'Configuration/EV_CodeSigning_Premium.php';
require_once 'Configuration/EmailIDBusiness_StandardCode.php';
require_once 'Configuration/Commercial.php';

use MGModule\CERTUM_Certificates\helpers\Configuration\Commercial;
use MGModule\CERTUM_Certificates\helpers\Configuration\DocumentSigning;
use MGModule\CERTUM_Certificates\helpers\Configuration\EmailIDBusiness_StandardCode;
use MGModule\CERTUM_Certificates\helpers\Configuration\EmailIdIndividual;
use MGModule\CERTUM_Certificates\helpers\Configuration\EV_CodeSigning_Premium;
use MGModule\CERTUM_Certificates\helpers\Configuration\S_Mime;
use MGModule\CERTUM_Certificates\helpers\Configuration\Trusted;

class CertificateConfiguration
{
    protected $productId;
    protected $productName;

    public function __construct($productId, $productName)
    {
        $this->productId = $productId;
        $this->productName = $productName;
    }

    public function get()
    {
        $fields = [];
        $fieldsCertificteDetails = $this->certificteDetailsSection();
        $fieldsContactDetails = $this->contactDetailsSection();
        $fields['additionalfields'] = array_merge($fieldsCertificteDetails['additionalfields'], $fieldsContactDetails['additionalfields']);
        return $fields;
    }

    protected function certificteDetailsSection()
    {
        $fields = [];

        if($this->productId == '731' || $this->productId == '732' || $this->productId == '733')
        {
            $emailIdIndividual = new EmailIdIndividual($this->productId);
            $fields['additionalfields'] = $emailIdIndividual->certificteDetailsSection();
        }

        if($this->productId == '501' || $this->productId == '502' || $this->productId == '511' || $this->productId == '512' || $this->productId == '521' || $this->productId == '522' || $this->productId == '531' || $this->productId == '532')
        {
            $SMIME = new S_Mime($this->productId);
            $fields['additionalfields'] = $SMIME->certificteDetailsSection();
        }

        if($this->productId == '281' || $this->productId == '282' || $this->productId == '283')
        {
            $DS = new DocumentSigning($this->productId);
            $fields['additionalfields'] = $DS->certificteDetailsSection();
        }

        if($this->productId == '316' || $this->productId == '317' || $this->productId == '318' || $this->productId == '641' || $this->productId == '981')
        {
            $EV = new EV_CodeSigning_Premium($this->productId);
            $fields['additionalfields'] = $EV->certificteDetailsSection();
        }

        if($this->productId == '631' || $this->productId == '681' || $this->productId == '971')
        {
            $trusted = new Trusted($this->productId);
            $fields['additionalfields'] = $trusted->certificteDetailsSection();
        }

        if($this->productId == '601' || $this->productId == '741' || $this->productId == '961')
        {
            $commercial = new Commercial($this->productId);
            $fields['additionalfields'] = $commercial->certificteDetailsSection();
        }

        if($this->productId == '831' || $this->productId == '832' || $this->productId == '833' || $this->productId == '721' || $this->productId == '722' || $this->productId == '723')
        {
            $emailIDBusiness_StandardCode = new EmailIDBusiness_StandardCode($this->productId);
            $fields['additionalfields'] = $emailIDBusiness_StandardCode->certificteDetailsSection();
        }

        return $fields;
    }

    protected function contactDetailsSection()
    {
        $fields = [];

        $previous_type = null;
        $contact_types = ['admin'];

        foreach ($contact_types as $t) {
            $field = ucfirst($t);
            $tr = CERTUM_Certificates_translate($t);

            // Default first & last name
            $fields['additionalfields'][$tr][$field . 'FirstName'] = array
            (
                'FriendlyName' => CERTUM_Certificates_translate('first_name').' *',
                'Type'         => 'text',
                'Size'         => '30',
                'Description'  => '<style type="text/css">#servertype,label[for=servertype] {display:none!important;}</style><script type="text/javascript">$(function(){
                            $("select[name=servertype]").val(1000);
                            //$("select[name=servertype]").closest(".control-group").hide();

                                $("input[name=\'fields[AdminLastName]\']").attr("placeholder","Doe");
                                $("input[name=\'fields[AdminFirstName]\']").attr("placeholder","John");
                                $("input[name=\'fields[AdminLastName]\']").attr("placeholder","Doe");
                                $("input[name=\'fields[AdminName]\']").attr("placeholder","Certum");
                                $("input[name=\'fields[AdminTax]\']").attr("placeholder","P90525548").attr("maxlength",20);
                                $("input[name=\'fields[AdminAddress1]\']").attr("placeholder","2800 South Alabama Ave");
                                $("input[name=\'fields[AdminCity]\']").attr("placeholder","Monroeville");
                                $("input[name=\'fields[AdminPostalCode]\']").attr("placeholder","36460");
                                $("input[name=\'fields[AdminPhone]\']").attr("placeholder","+480000000000");
                                $("input[name=\'fields[AdminVerificationPhone]\']").attr("placeholder","+480000000000");
                                $("input[name=\'fields[AdminEmail]\']").attr("placeholder","test@example.com");
                                
                                $( "<p>'.CERTUM_Certificates_translate('ov_ev_contact_desc').'</p>" ).insertBefore($("input[name=\'fields[AdminLastName]\']").parents(".form-horizontal"));
                            });
                            $("#csr").closest("div").css("margin-left","125px");
                            $("label[for=csr]").css("width","125px").css("text-align","left");
                            $("label[for=csr]").closest("div").css("margin-top","10px");
                            $("select[name=\'fields[AdminCountry]\'").css("width","220px").hide();


                            ' . (isset($_POST['csr']) && !empty($_POST['csr']) ? '$("#csr").text("' . str_replace("\r", '\n\\', $_POST['csr']) . '");' : '') . '
                            </script>',
                'Required'     => $t != 'organization' ? true : false,
            );
            $fields['additionalfields'][$tr][$field . 'LastName'] = array
            (
                'FriendlyName' => CERTUM_Certificates_translate('last_name').' *',
                'Type'         => 'text',
                'Size'         => '30',
                'Description'  => '',
                'Required'     => $t != 'organization' ? true : false,
            );


            if(
                $this->productId != '831' && $this->productId != '832' && $this->productId != '833' &&
                $this->productId != '721' && $this->productId != '722' && $this->productId != '723' &&
                $this->productId != '731' && $this->productId != '732' && $this->productId != '733' &&
                $this->productId != '501' && $this->productId != '502'
            )
            {

                // EV & Trusted Name
                if (strpos($this->productName, 'Trusted') !== false) {
                    $fields['additionalfields'][$tr][$field . 'Name'] = array
                    (
                        'FriendlyName' => CERTUM_Certificates_translate('organization').' *',
                        'Type'         => 'text',
                        'Size'         => '30',
                        'Description'  => '',
                        'Required'     => true,
                    );
                }
                else if (strpos($this->productName, 'EV') !== false) {
                    $fields['additionalfields'][$tr][$field . 'Name'] = array
                    (
                        'FriendlyName' => CERTUM_Certificates_translate('organization').' *',
                        'Type'         => 'text',
                        'Size'         => '30',
                        'Description'  => '',
                        'Required'     => true,
                    );
                }
                else {
                    $fields['additionalfields'][$tr][$field . 'Name'] = array
                    (
                        'FriendlyName' => CERTUM_Certificates_translate('organization'),
                        'Type'         => 'text',
                        'Size'         => '30',
                        'Description'  => '',
                        'Required'     => false,
                    );
                }

                // EV & Trusted serial number
                if (strpos($this->productName, 'EV') !== false) {
                    $fields['additionalfields'][$tr][$field . 'SerialNumber'] = array
                    (
                        'FriendlyName' => CERTUM_Certificates_translate('Serial Number').' *',
                        'Type'         => 'text',
                        'Size'         => '30',
                        'Description'  => '',
                        'Required'     => true,
                    );
                }
                else if (strpos($this->productName, 'Trusted') !== false) {
                    $fields['additionalfields'][$tr][$field . 'SerialNumber'] = array
                    (
                        'FriendlyName' => CERTUM_Certificates_translate('Serial Number'),
                        'Type'         => 'text',
                        'Size'         => '30',
                        'Description'  => '',
                        'Required'     => false,
                    );
                }
            }

            // Default Phone & email
            $fields['additionalfields'][$tr][$field . 'Phone'] = array
            (
                'FriendlyName' => CERTUM_Certificates_translate('phone'),
                'Type'         => 'text',
                'Size'         => '30',
                'Description'  => CERTUM_Certificates_translate('phone_description'),
                'Required'     => false,
            );
            $fields['additionalfields'][$tr][$field . 'Email'] = array
            (
                'FriendlyName' => CERTUM_Certificates_translate('email').' *',
                'Type'         => 'text',
                'Size'         => '30',
                'Description'  => '',
                'Required'     => true,
            );


            // EV fields
            if (strpos($this->productName, 'EV') !== false) {
                $fields['additionalfields'][$tr][$field . 'Locality'] = array
                (
                    'FriendlyName' => CERTUM_Certificates_translate('Locality').' *',
                    'Type'         => 'text',
                    'Size'         => '30',
                    'Description'  => '',
                    'Required'     => false,
                );
                $fields['additionalfields'][$tr][$field . 'StateProvince'] = array
                (
                    'FriendlyName' => CERTUM_Certificates_translate('State/Province').' *',
                    'Type'         => 'text',
                    'Size'         => '30',
                    'Description'  => 'Locality or State/Province is required.',
                    'Required'     => false,
                );
                $fields['additionalfields'][$tr][$field . 'BusinessCategory'] = array
                (
                    'FriendlyName' => CERTUM_Certificates_translate('BusinessCategory').' *',
                    'Type'         => 'dropdown',
                    'Size'         => '30',
                    'Description'  => '',
                    'Options'      => 'Please choose...,Private Organization,Government Entity,Business Entity,Non-Commercial Entity',
                    'Required'     => true,
                );
                $fields['additionalfields'][$tr][$field . 'Joisocn'] = array
                (
                    'FriendlyName' => CERTUM_Certificates_translate('JoISoCN').' *',
                    'Type'         => 'country',
                    'Size'         => '30',
                    'Description'  => '',
                    'Required'     => true,
                );
            }

            // Trusted fields
            if (strpos($this->productName, 'Trusted') !== false) {
                $fields['additionalfields'][$tr][$field . 'Locality'] = array
                (
                    'FriendlyName' => CERTUM_Certificates_translate('Locality').' *',
                    'Type'         => 'text',
                    'Size'         => '30',
                    'Description'  => '',
                    'Required'     => false,
                );

                $fields['additionalfields'][$tr][$field . 'StateProvince'] = array
                (
                    'FriendlyName' => CERTUM_Certificates_translate('State/Province').' *',
                    'Type'         => 'text',
                    'Size'         => '30',
                    'Description'  => 'Locality or State/Province is required.',
                    'Required'     => false,
                );
            }

            if($this->productId == '316' || $this->productId == '317' || $this->productId == '318' || $this->productId == '641' || $this->productId == '981')
            {
                $fields['additionalfields'][$tr] = [];
                $EV = new EV_CodeSigning_Premium($this->productId);
                $fields['additionalfields'][$tr] = $EV->contactDetailsSection($field, $t);
            }

            if($this->productId == '631' || $this->productId == '681' || $this->productId == '971')
            {
                $fields['additionalfields'][$tr] = [];
                $trusted = new Trusted($this->productId);
                $fields['additionalfields'][$tr] = $trusted->contactDetailsSection($field, $t);
            }

            if($this->productId == '511' || $this->productId == '512' || $this->productId == '521' || $this->productId == '522' || $this->productId == '531' || $this->productId == '532')
            {
                $fields['additionalfields'][$tr] = [];
                $sMime = new S_Mime($this->productId);
                $fields['additionalfields'][$tr] = $sMime->contactDetailsSection($field, $t);
            }

            if(
                $this->productId == '601' || $this->productId == '741' || $this->productId == '961' ||
                $this->productId == '691' || $this->productId == '791' ||
                $this->productId == '731' || $this->productId == '732' || $this->productId == '733' ||
                $this->productId == '501' || $this->productId == '502'
            )
            {
                $fields['additionalfields'][$tr] = array();
                $commercial = new Commercial($this->productId);
                $fields['additionalfields'][$tr] = $commercial->contactDetailsSection($field, $t);
            }

            if($this->productId == '281' || $this->productId == '282' || $this->productId == '283')
            {
                $fields['additionalfields'][$tr] = [];
                $documentSigning = new DocumentSigning($this->productId);
                $fields['additionalfields'][$tr] = $documentSigning->contactDetailsSection($field, $t);
            }

            $previous_type = $t;
        }
        return $fields;
    }
}