<?php

namespace MGModule\CERTUM_Certificates\helpers;

use WHMCS\Database\Capsule as DB;
use MGModule\CERTUM_Certificates\helpers\Whmcs\Product;

class SslService
{
    private $configuration;
    private $apiHandler;
    
    public function __construct($serviceId = null)
    {
        $details = DB::table('tblsslorders')->where('serviceid', '=', $serviceId)->first();
        
        if($details->id)
        {
            $this->configuration = $details;
        }
    }
    
    public function setApiHandler($api)
    {
        $this->apiHandler = $api;
    }

    public function getCertificates()
    {
        if(!$this->configuration->remoteid)
        {
            return;
        }

        $allCertificates = [];

        $op = $this->apiHandler->operationGetOrderByOrderID();
        $op->setOrderID($this->configuration->remoteid)->setOrderStatus(TRUE)->setCertificateDetails(TRUE)->setOrderDetails(TRUE);
 
        if ($op->call()) {
            $allCertificates = $op->getOrders();
        }

        return $allCertificates;
    }

    public function getLastCertificateSerialNumber()
    {
        $allCertificates = $this->getCertificates();

        $certs = [];

        foreach($allCertificates as $c)
        {
            if($c->certificateDetails->certificateStatus == 'VALID')
            {
                $dateTime = new \DateTime($c->certificateDetails->startDate); 
                $startdate = $dateTime->format('Y-m-d H:i:s'); 
                $certs[] = array(
                    'date' => $startdate,
                    'time' => strtotime($startdate),
                    'number' => $c->certificateDetails->serialNumber,
                );
            }
        }
        
        $certsnew = array_sort_new($certs, 'time', SORT_DESC);
        $lastcsr = reset($certsnew);

        return $lastcsr;
    }
    
    public function getLastCertificateDNS()
    {
        $allCertificates = $this->getCertificates();

        $certs = [];

        foreach($allCertificates as $c)
        {
            if($c->certificateDetails->certificateStatus == 'VALID')
            {
                $dateTime = new \DateTime($c->certificateDetails->startDate); 
                $startdate = $dateTime->format('Y-m-d H:i:s'); 
                $certs[] = array(
                    'date' => $startdate,
                    'time' => strtotime($startdate),
                    'number' => $c->certificateDetails->serialNumber,
                    'DNSNames' => $c->certificateDetails->DNSNames
                );
            }
        }
        
        if(empty($certs))
        {
            return false;
        }
        
        $certsnew = array_sort_new($certs, 'time', SORT_DESC);
        $lastcsr = reset($certsnew);

        if(!isset($lastcsr['DNSNames']) || empty($lastcsr['DNSNames']))
        {
            return false;
        }
      
        return explode(',', $lastcsr['DNSNames']);
    }

    public function getMainDomain()
    {
        $details = DB::table('tblhosting')->where('id', '=', $this->configuration->serviceid)->first();
       
        if($details->id)
        {
            return $details->domain;
        }

        return null;
    }
}